"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _Object$defineProperty = require("@babel/runtime-corejs2/core-js/object/define-property");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports["default"] = void 0;

var _keys = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/object/keys"));

var _typeof2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/typeof"));

var _isArray = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/array/is-array"));

var _parseFloat2 = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/parse-float"));

var BYTE_MAX_VALUE = 127,
    BYTE_MIN_VALUE = -128,
    DOUBLE_MAX_VALUE = 1.7976931348623157E308,
    DOUBLE_MIN_VALUE = 4.9E-324,
    FLOAT_MAX_VALUE = 3.4028235E38,
    FLOAT_MIN_VALUE = 1.4E-45,
    INT_MAX_VALUE = 2147483647,
    INT_MIN_VALUE = -2147483648,
    LONG_MAX_VALUE = 9223372036854776000,
    // actual value = 9223372036854775807,
LONG_MIN_VALUE = -9223372036854776000,
    // actual value = -9223372036854775808,
SHORT_MAX_VALUE = 32767,
    SHORT_MIN_VALUE = -32768,
    VALID_GEO_SHAPE_TYPES = ['point', 'linestring', 'polygon', 'multipoint', 'multilinestring', 'multipolygon', 'geometrycollection', 'envelope', 'circle'];

var echo = function echo(value) {
  return value;
},
    // length is a multiple of 8, has valid chars and is padded properly with "="
reBase32 = /^([a-z2-7]{8})*([a-z2-7]{8}|[a-z2-7]{2}={6}|[a-z2-7]{4}={4}|[a-z2-7]{5}={3}|[a-z2-7]{7}=)$/i,
    // length is a multiple of 4, has valid chars and is padded properly with "="
reBase64 = /^([a-z\d+/]{4})*([a-z\d+/]{4}|[a-z\d+/]{3}=|[a-z\d+/]{2}==)$/i,
    reBoolean = /^(true|on|yes|1|false|off|no|0)$/i,
    reIPv4 = /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/,
    reISO8601 = /^([\+-]?\d{4}(?!\d{2}\b))((-?)((0[1-9]|1[0-2])(\3([12]\d|0[1-9]|3[01]))?|W([0-4]\d|5[0-2])(-?[1-7])?|(00[1-9]|0[1-9]\d|[12]\d{2}|3([0-5]\d|6[1-6])))([T\s]((([01]\d|2[0-3])((:?)[0-5]\d)?|24\:?00)([\.,]\d+(?!:))?)?(\17[0-5]\d([\.,]\d+)?)?([zZ]|([\+-])([01]\d|2[0-3]):?([0-5]\d)?)?)?)?$/; // https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-attachment-type.html


function attachment(field) {
  return function (value) {
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && typeof value !== 'string', !isUndefined(value) && !reBase64.test(value)].some(echo);
  };
} // https://www.elastic.co/guide/en/elasticsearch/reference/master/binary.html


function binary(field) {
  return function (value) {
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && typeof value !== 'string', !isUndefined(value) && !reBase64.test(value)].some(echo);
  };
} // https://www.elastic.co/guide/en/elasticsearch/reference/master/boolean.html


function _boolean(field) {
  return function (value) {
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && typeof value === 'string' && !reBoolean.test(value), !isUndefined(value) && typeof value !== 'string' && typeof value !== 'boolean' && typeof value !== 'number'].some(echo);
  };
} // https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-core-types.html#number


function _byte(field) {
  return function (value) {
    var parsedValue = Number(value);
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && isNaN(parsedValue), !isUndefined(value) && parsedValue < BYTE_MIN_VALUE, !isUndefined(value) && parsedValue > BYTE_MAX_VALUE].some(echo);
  };
}

function clone(source) {
  if (isUndefined(source)) {
    return source;
  }

  var target = {};

  for (var property in source) {
    if (source.hasOwnProperty(property)) {
      if (isPOJO(source[property])) {
        target[property] = clone(source[property]);
      } else {
        target[property] = source[property];
      }
    }
  }

  return target;
} // https://www.elastic.co/guide/en/elasticsearch/reference/master/date.html


function date(field) {
  return function (value) {
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && typeof value !== 'number' && typeof value !== 'string' && !(value instanceof Date), !isUndefined(value) && typeof value === 'string' && !reISO8601.test(value) && isNaN(new Date(value))].some(echo);
  };
} // https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-core-types.html#number


function _double(field) {
  return function (value) {
    var parsedValue = (0, _parseFloat2["default"])(value);

    if (parsedValue === 0) {
      return true;
    }

    return ![isMissingWhenRequired(field, value), !isUndefined(value) && isNaN(parsedValue), !isUndefined(value) && parsedValue < DOUBLE_MIN_VALUE, !isUndefined(value) && parsedValue > DOUBLE_MAX_VALUE].some(echo);
  };
} // https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-core-types.html#number


function _float(field) {
  return function (value) {
    var parsedValue = (0, _parseFloat2["default"])(value);

    if (parsedValue === 0) {
      return true;
    }

    return ![isMissingWhenRequired(field, value), !isUndefined(value) && isNaN(parsedValue), !isUndefined(value) && parsedValue < FLOAT_MIN_VALUE, !isUndefined(value) && parsedValue > FLOAT_MAX_VALUE].some(echo);
  };
} // https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-geo-point-type.html

/* eslint camelcase : 0 */


function geo_point(field) {
  return function (value) {
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && (0, _isArray["default"])(value) && (value.length !== 2 || isNaN(value[0]) || isNaN(value[1])), !isUndefined(value) && (0, _typeof2["default"])(value) === 'object' && !(0, _isArray["default"])(value) && (isUndefined(value.lat) || isUndefined(value.lon)), !isUndefined(value) && typeof value === 'string' && /\,/.test(value) && value.split(/\,/).length !== 2, !isUndefined(value) && typeof value === 'string' && !/\,/.test(value) && !reBase32.test(value)].some(echo);
  };
} // https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-geo-shape-type.html

/* eslint camelcase : 0 */


function geo_shape(field) {
  return function (value) {
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && value.type !== 'geometrycollection' && (!value.type || !value.coordinates), !isUndefined(value) && value.type === 'geometrycollection' && (!value.type || !value.geometries), !isUndefined(value) && value.type === 'geometrycollection' && value.geometries && value.geometries.some(function (coords) {
      return !geo_shape(field)(coords);
    }), !isUndefined(value) && VALID_GEO_SHAPE_TYPES.indexOf(value.type) < 0].some(echo);
  };
} // https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-core-types.html#number


function integer(field) {
  return function (value) {
    var parsedValue = Number(value);
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && isNaN(parsedValue), !isUndefined(value) && parsedValue < INT_MIN_VALUE, !isUndefined(value) && parsedValue > INT_MAX_VALUE].some(echo);
  };
} // https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-ip-type.html


function ip(field) {
  return function (value) {
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && typeof value !== 'string', !isUndefined(value) && !reIPv4.test(value)].some(echo);
  };
}

function isMissingWhenRequired(field, value) {
  if (field && field.required && typeof field.required === 'boolean') {
    return isUndefined(value) || isPOJO(value) && !(0, _keys["default"])(value).length || typeof value === 'string' && !value.length;
  }

  return false;
}

function isPOJO(value) {
  return ![value === null, typeof value === 'undefined', (0, _typeof2["default"])(value) !== 'object', (0, _isArray["default"])(value), value && value.toString && !/^\[object\sObject\]$/.test(value.toString())].some(echo);
}

function isUndefined(value) {
  return value === null || typeof value === 'undefined';
} // https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-core-types.html#number


function _long(field) {
  return function (value) {
    var parsedValue = Number(value);
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && isNaN(parsedValue), !isUndefined(value) && parsedValue < LONG_MIN_VALUE, !isUndefined(value) && parsedValue > LONG_MAX_VALUE].some(echo);
  };
} // https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-object-type.html


function object(field) {
  return function (value) {
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && (0, _typeof2["default"])(value) !== 'object'].some(echo);
  };
} // https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-core-types.html#number


function _short(field) {
  return function (value) {
    var parsedValue = Number(value);
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && isNaN(parsedValue), !isUndefined(value) && parsedValue < SHORT_MIN_VALUE, !isUndefined(value) && parsedValue > SHORT_MAX_VALUE].some(echo);
  };
}

function string(field) {
  return function (value) {
    return ![isMissingWhenRequired(field, value), !isUndefined(value) && (isPOJO(value) || (0, _isArray["default"])(value) || typeof value.toString === 'undefined')].some(echo);
  };
}

var _default = {
  attachment: attachment,
  binary: binary,
  "boolean": _boolean,
  "byte": _byte,
  clone: clone,
  date: date,
  "double": _double,
  "float": _float,
  geo_point: geo_point,
  geo_shape: geo_shape,
  integer: integer,
  ip: ip,
  isPOJO: isPOJO,
  isUndefined: isUndefined,
  keyword: string,
  "long": _long,
  object: object,
  "short": _short,
  string: string,
  text: string
};
exports["default"] = _default;
//# sourceMappingURL=validators.js.map
